# -*- coding:utf-8; eval: (blacken-mode) -*-

import logging


logger = logging.getLogger(__name__)


def _init_logging():
    import logging.config

    cfg = {
        "version": 1,
        "formatters": {
            "standard": {
                "format": "%(asctime)s %(name)s %(levelname)s: %(message)s",
            }
        },
        "handlers": {
            "default": {
                "class": "logging.StreamHandler",
                "formatter": "standard",
                "stream": "ext://sys.stdout",
            }
        },
        "loggers": {
            "usadelndsoc": {
                "handlers": ["default"],
                "level": "INFO",
                "propagate": True,
            },
        },
    }

    logging.config.dictConfig(cfg)


def with_log_level(level):
    import functools

    def deco(func):
        @functools.wraps(func)
        def wrapper(*a, **kw):
            old_level = int(logger.level)
            logger.setLevel(level)
            try:
                return func(*a, **kw)
            finally:
                logger.setLevel(old_level)

        return wrapper

    return deco


_init_logging()
del _init_logging, logging
